/*
 * CoverFinder - Find and download cover images from Amazon
 * Copyright (C) 2007 - 2008 - Sven Salzwedel
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "cf-search.h"

enum
{
	SEARCH_NOPROP, SEARCH_TITLE, SEARCH_ARTIST, SEARCH_KEYWORDS
};

G_DEFINE_TYPE (CfSearch, cf_search, G_TYPE_OBJECT)

static void cf_search_finalize (GObject *object)
{
	CfSearch *self = CF_SEARCH (object);

	if (G_OBJECT_CLASS (cf_search_parent_class)->finalize)
		G_OBJECT_CLASS (cf_search_parent_class)->finalize (object);
	g_free (self->artist);
	g_free (self->title);
	g_free (self->keywords);
}

static void cf_search_get_property (GObject *object, guint property_id,
	GValue *value, GParamSpec *pspec)
{
	CfSearch *self = CF_SEARCH (object);

	switch (property_id) {
	case SEARCH_ARTIST:
		g_value_set_string (value, self->artist);
		break;
	case SEARCH_TITLE:
		g_value_set_string (value, self->title);
		break;
	case SEARCH_KEYWORDS:
		g_value_set_string (value, self->keywords);
		break;
	default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
	}
}

static void cf_search_set_property (GObject *object, guint property_id,
	const GValue *value, GParamSpec *pspec)
{
	CfSearch *self = CF_SEARCH (object);

	switch (property_id) {
	case SEARCH_ARTIST:
		self->artist = g_value_dup_string (value);
		break;
	case SEARCH_TITLE:
		self->title = g_value_dup_string (value);
		break;
	case SEARCH_KEYWORDS:
		self->keywords = g_value_dup_string (value);
		break;
	default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
	}
}

static void cf_search_class_init (CfSearchClass *klass)
{
	GObjectClass *object_class = G_OBJECT_CLASS (klass);
	GParamSpec *spec;

	object_class->get_property = cf_search_get_property;
	object_class->set_property = cf_search_set_property;
	object_class->finalize = cf_search_finalize;

	spec = g_param_spec_string ("title", NULL, NULL, NULL, G_PARAM_READWRITE);
	g_object_class_install_property (object_class, SEARCH_TITLE, spec);

	spec = g_param_spec_string ("artist", NULL, NULL, NULL, G_PARAM_READWRITE);
	g_object_class_install_property (object_class, SEARCH_ARTIST, spec);

	spec
		= g_param_spec_string ("keywords", NULL, NULL, NULL, G_PARAM_READWRITE);
	g_object_class_install_property (object_class, SEARCH_KEYWORDS, spec);
}

static void cf_search_init (CfSearch *self)
{
}

CfSearch*
cf_search_new (void)
{
	return g_object_new (CF_TYPE_SEARCH, NULL);
}
